@@ -12,20 +12,24 @@ require Type::Tiny;
 our $CALLER   = caller;
 our @DEFAULTS = 'Types::Standard';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 unshift @Function::Parameters::type_reifiers => sub {
     Type::Registry->for_class($CALLER)->lookup($_[0]);
 };
 
 sub import {
-    my (@CONFIG, @LIBRARIES);
+    my (@ARGUMENTS, @LIBRARIES);
+
     for (map 'ARRAY' eq ref $_ ? @$_ : $_, splice @_, 1) {
-        push @LIBRARIES, $_ and next if !ref && !/^:/;
-        push @CONFIG,    $_;
+        push @LIBRARIES => $_ and next if !ref && !/^:/;
+        push @ARGUMENTS => $_;
     }
+
     Type::Registry->for_class($CALLER)->add_types($_) for @DEFAULTS, @LIBRARIES;
-    Function::Parameters->import(@CONFIG);
+    Function::Parameters->import(@ARGUMENTS);
+
+    return;
 }
 
 1;
@@ -42,7 +46,7 @@ Type::Tiny::Signatures - Method/Function Signatures w/Type::Tiny Constraints
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
